# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class SceneType(Enum):
    OPENING_TITLES = "OPENING_TITLES"
    EPISODE_TITLE_CARD = "EPISODE_TITLE_CARD"
    STUDIO_LOGO_BUMPER = "STUDIO_LOGO_BUMPER"
    NETWORK_OR_PLATFORM_IDENT = "NETWORK_OR_PLATFORM_IDENT"
    RECAP = "RECAP"
    PREVIEW_THIS_TITLE = "PREVIEW_THIS_TITLE"
    PROMO_OTHER_TITLE = "PROMO_OTHER_TITLE"
    TRAILER_OTHER_TITLE = "TRAILER_OTHER_TITLE"
    ADS = "ADS"
    ACT_BREAK_EYECATCH = "ACT_BREAK_EYECATCH"
    TECHNICAL_SLATE_OR_TEST = "TECHNICAL_SLATE_OR_TEST"
    MAIN_CONTENT = "MAIN_CONTENT"
    MID_CREDIT_SCENE = "MID_CREDIT_SCENE"
    POST_CREDIT_SCENE = "POST_CREDIT_SCENE"
    END_CREDITS = "END_CREDITS"
    UNKNOWN = "UNKNOWN"
