# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class CloudRegion(Enum):
    AWS_US_EAST_1 = "AWS_US_EAST_1"
    AWS_US_EAST_2 = "AWS_US_EAST_2"
    AWS_US_WEST_1 = "AWS_US_WEST_1"
    AWS_US_WEST_2 = "AWS_US_WEST_2"
    AWS_EU_WEST_1 = "AWS_EU_WEST_1"
    AWS_EU_CENTRAL_1 = "AWS_EU_CENTRAL_1"
    AWS_AP_SOUTHEAST_1 = "AWS_AP_SOUTHEAST_1"
    AWS_AP_SOUTHEAST_2 = "AWS_AP_SOUTHEAST_2"
    AWS_AP_NORTHEAST_1 = "AWS_AP_NORTHEAST_1"
    AWS_AP_NORTHEAST_2 = "AWS_AP_NORTHEAST_2"
    AWS_AP_SOUTH_1 = "AWS_AP_SOUTH_1"
    AWS_SA_EAST_1 = "AWS_SA_EAST_1"
    AWS_EU_WEST_2 = "AWS_EU_WEST_2"
    AWS_EU_WEST_3 = "AWS_EU_WEST_3"
    AWS_CA_CENTRAL_1 = "AWS_CA_CENTRAL_1"
    AWS_EU_NORTH_1 = "AWS_EU_NORTH_1"
    GOOGLE_US_CENTRAL_1 = "GOOGLE_US_CENTRAL_1"
    GOOGLE_US_EAST_1 = "GOOGLE_US_EAST_1"
    GOOGLE_ASIA_EAST_1 = "GOOGLE_ASIA_EAST_1"
    GOOGLE_EUROPE_WEST_1 = "GOOGLE_EUROPE_WEST_1"
    GOOGLE_US_WEST_1 = "GOOGLE_US_WEST_1"
    GOOGLE_ASIA_EAST_2 = "GOOGLE_ASIA_EAST_2"
    GOOGLE_ASIA_NORTHEAST_1 = "GOOGLE_ASIA_NORTHEAST_1"
    GOOGLE_ASIA_SOUTH_1 = "GOOGLE_ASIA_SOUTH_1"
    GOOGLE_ASIA_SOUTHEAST_1 = "GOOGLE_ASIA_SOUTHEAST_1"
    GOOGLE_AUSTRALIA_SOUTHEAST_1 = "GOOGLE_AUSTRALIA_SOUTHEAST_1"
    GOOGLE_EUROPE_NORTH_1 = "GOOGLE_EUROPE_NORTH_1"
    GOOGLE_EUROPE_WEST_2 = "GOOGLE_EUROPE_WEST_2"
    GOOGLE_EUROPE_WEST_3 = "GOOGLE_EUROPE_WEST_3"
    GOOGLE_EUROPE_WEST_4 = "GOOGLE_EUROPE_WEST_4"
    GOOGLE_NORTHAMERICA_NORTHEAST_1 = "GOOGLE_NORTHAMERICA_NORTHEAST_1"
    GOOGLE_SOUTHAMERICA_EAST_1 = "GOOGLE_SOUTHAMERICA_EAST_1"
    GOOGLE_US_EAST_4 = "GOOGLE_US_EAST_4"
    GOOGLE_US_WEST_2 = "GOOGLE_US_WEST_2"
    GOOGLE_ME_CENTRAL_2 = "GOOGLE_ME_CENTRAL_2"
    AZURE_ASIA_EAST = "AZURE_ASIA_EAST"
    AZURE_ASIA_SOUTHEAST = "AZURE_ASIA_SOUTHEAST"
    AZURE_AUSTRALIA_EAST = "AZURE_AUSTRALIA_EAST"
    AZURE_AUSTRALIA_SOUTHEAST = "AZURE_AUSTRALIA_SOUTHEAST"
    AZURE_BRAZIL_SOUTH = "AZURE_BRAZIL_SOUTH"
    AZURE_CANADA_CENTRAL = "AZURE_CANADA_CENTRAL"
    AZURE_EUROPE_NORTH = "AZURE_EUROPE_NORTH"
    AZURE_EUROPE_WEST = "AZURE_EUROPE_WEST"
    AZURE_FRANCE_CENTRAL = "AZURE_FRANCE_CENTRAL"
    AZURE_GERMANY_WESTCENTRAL = "AZURE_GERMANY_WESTCENTRAL"
    AZURE_INDIA_CENTRAL = "AZURE_INDIA_CENTRAL"
    AZURE_INDIA_SOUTH = "AZURE_INDIA_SOUTH"
    AZURE_JAPAN_EAST = "AZURE_JAPAN_EAST"
    AZURE_JAPAN_WEST = "AZURE_JAPAN_WEST"
    AZURE_KOREA_CENTRAL = "AZURE_KOREA_CENTRAL"
    AZURE_UAE_NORTH = "AZURE_UAE_NORTH"
    AZURE_US_CENTRAL = "AZURE_US_CENTRAL"
    AZURE_US_EAST = "AZURE_US_EAST"
    AZURE_US_EAST2 = "AZURE_US_EAST2"
    AZURE_US_WEST = "AZURE_US_WEST"
    AZURE_US_WEST2 = "AZURE_US_WEST2"
    AZURE_US_SOUTH_CENTRAL = "AZURE_US_SOUTH_CENTRAL"
    AZURE_US_NORTH_CENTRAL = "AZURE_US_NORTH_CENTRAL"
    AZURE_UK_SOUTH = "AZURE_UK_SOUTH"
    AKAMAI_BR_GRU = "AKAMAI_BR_GRU"
    AKAMAI_ES_MAD = "AKAMAI_ES_MAD"
    AKAMAI_FR_PAR = "AKAMAI_FR_PAR"
    AKAMAI_ID_CGK = "AKAMAI_ID_CGK"
    AKAMAI_IN_MAA = "AKAMAI_IN_MAA"
    AKAMAI_IT_MIL = "AKAMAI_IT_MIL"
    AKAMAI_JP_OSA = "AKAMAI_JP_OSA"
    AKAMAI_NL_AMS = "AKAMAI_NL_AMS"
    AKAMAI_SE_STO = "AKAMAI_SE_STO"
    AKAMAI_US_LAX = "AKAMAI_US_LAX"
    AKAMAI_US_MIA = "AKAMAI_US_MIA"
    AKAMAI_US_ORD = "AKAMAI_US_ORD"
    AKAMAI_US_SEA = "AKAMAI_US_SEA"
    OCI_EU_FRANKFURT_1 = "OCI_EU_FRANKFURT_1"
    OCI_US_ASHBURN_1 = "OCI_US_ASHBURN_1"
    NORTH_AMERICA = "NORTH_AMERICA"
    SOUTH_AMERICA = "SOUTH_AMERICA"
    EUROPE = "EUROPE"
    AFRICA = "AFRICA"
    ASIA = "ASIA"
    AUSTRALIA = "AUSTRALIA"
    AWS = "AWS"
    GOOGLE = "GOOGLE"
    EXTERNAL = "EXTERNAL"
    AUTO = "AUTO"
